@@ -1,33 +1,22 @@
 setGeneric("abstract",        function(object) standardGeneric("abstract"))
 setGeneric("aggenv",          function(object) standardGeneric("aggenv"))
 setGeneric("aggfun",          function(object) standardGeneric("aggfun"))
-setGeneric("annotation",      function(object) standardGeneric("annotation"))
-setGeneric("annotation<-",    function(object, value) standardGeneric("annotation<-"))
 setGeneric("annotatedDataFrameFrom", function(object, byrow, ...) standardGeneric("annotatedDataFrameFrom"))
 setGeneric("assayData",       function(object)standardGeneric("assayData"))
 setGeneric("assayData<-",     function(object, value) standardGeneric("assayData<-"))
 setGeneric("channelNames",    function(object, ...) standardGeneric("channelNames"))
 setGeneric("channel",         function(object, name, ...) standardGeneric("channel"))
-setGeneric("combine",
-           function(x, y, ...) {
-               if (length(list(...)) > 0) {
-                   callGeneric(x, do.call(callGeneric,
-                                          list(y, ...)))
-               } else {
-                   standardGeneric("combine")
-               }
-           })
 setGeneric("content",         function(object) standardGeneric("content"))
 setGeneric("description",     function(object, ...)
            standardGeneric("description"))
 setGeneric("description<-",   function(object, value) standardGeneric("description<-"))
 setGeneric("dims",            function(object) standardGeneric("dims"))
+setGeneric("dimnames")
+setGeneric("dimnames<-")
 setGeneric("dimLabels",       function(object) standardGeneric("dimLabels"))
 setGeneric("dimLabels<-",     function(object, value) standardGeneric("dimLabels<-"))
 setGeneric("esApply",          function(X, MARGIN, FUN, ...) standardGeneric("esApply"),
            signature=c("X"))
-setGeneric("eList",           function(object) standardGeneric("eList"))
-setGeneric("eList<-",         function(object, value) standardGeneric("eList<-"))
 setGeneric("experimentData",  function(object) standardGeneric("experimentData"))
 setGeneric("experimentData<-",function(object, value) standardGeneric("experimentData<-"))
 setGeneric("expinfo",         function(object) standardGeneric("expinfo"))
@@ -43,9 +32,6 @@ setGeneric("fvarLabels",      function(object) standardGeneric("fvarLabels"))
 setGeneric("fvarLabels<-",    function(object, value) standardGeneric("fvarLabels<-"))
 setGeneric("fvarMetadata",    function(object) standardGeneric("fvarMetadata"))
 setGeneric("fvarMetadata<-",  function(object, value) standardGeneric("fvarMetadata<-"))
-setGeneric("geneNames",       function(object) standardGeneric("geneNames"))
-setGeneric("geneNames<-",     function(object, value) standardGeneric("geneNames<-"))
-setGeneric("getExpData",      function(object, name) standardGeneric("getExpData"))
 setGeneric("hybridizations",  function(object) standardGeneric("hybridizations"))
 setGeneric("initfun",         function(object) standardGeneric("initfun"))
 setGeneric("locked",          function(object) standardGeneric("locked"))
@@ -70,8 +56,6 @@ setGeneric("protocolData",    function(object) standardGeneric("protocolData"))
 setGeneric("protocolData<-",  function(object, value) standardGeneric("protocolData<-"))
 setGeneric("pubMedIds",       function(object) standardGeneric("pubMedIds"))
 setGeneric("pubMedIds<-",     function(object, value) standardGeneric("pubMedIds<-"))
-setGeneric("reporterNames",   function(object) standardGeneric("reporterNames"))
-setGeneric("reporterNames<-", function(object, value) standardGeneric("reporterNames<-"))
 setGeneric("sampleNames",     function(object) standardGeneric("sampleNames"))
 setGeneric("sampleNames<-",   function(object, value) standardGeneric("sampleNames<-"))
 setGeneric("samples",         function(object) standardGeneric("samples"))
@@ -95,13 +79,7 @@ setGeneric("classVersion",    function(object) standardGeneric("classVersion"))
 setGeneric("classVersion<-",  function(object, value) standardGeneric("classVersion<-"))
 setGeneric("isCurrent",       function(object, value) standardGeneric("isCurrent"))
 setGeneric("isVersioned",     function(object) standardGeneric("isVersioned"))
-## updateObject
-setGeneric("updateObject",
-           function(object, ..., verbose=FALSE) {
-               result <- standardGeneric("updateObject")
-               validObject(result)
-               result
-           })
+## updateObjectTo
 setGeneric("updateObjectTo",
            function(object, template, ..., verbose=FALSE) {
                result <- standardGeneric("updateObjectTo")
