@@ -1,37 +1,48 @@
 setMethod("initialize", signature(.Object="AnnotatedDataFrame"),
-          function(.Object, data = data.frame(), varMetadata = data.frame(),...) {
-              tryCatch({
-                  if (missing(varMetadata)) {
-                      if (!missing(data)) checkClass(data, "data.frame", class(.Object))
-                      varMetadata <- data.frame(labelDescription = rep(NA, ncol(data)))
-                      row.names(varMetadata) <- as.character(colnames(data))
-                  } else {
-                      checkClass(varMetadata, "data.frame", class(.Object))
-                      if (!"labelDescription" %in% colnames(varMetadata))
-                          varMetadata[["labelDescription"]] <- rep(NA, nrow(varMetadata))
-                      row.names(varMetadata) <- names(data)
-                  }
-                  varMetadata[["labelDescription"]] <- as.character(varMetadata[["labelDescription"]])
-              }, error=function(err) {
-                  stop(conditionMessage(err),
-                       "\n  AnnotatedDataFrame 'initialize' could not update varMetadata:",
-                       "\n  perhaps pData and varMetadata are inconsistent?")
-              })
-              callNextMethod(.Object, data=data, varMetadata=varMetadata, ...)
-          })
+          function(.Object, data = data.frame(), varMetadata = data.frame(),
+                   ...)
+{
+    tryCatch({
+        if (missing(varMetadata)) {
+            if (!missing(data)) checkClass(data, "data.frame", class(.Object))
+            varMetadata <- data.frame(labelDescription = rep(NA, ncol(data)))
+            row.names(varMetadata) <- as.character(colnames(data))
+        } else {
+            checkClass(varMetadata, "data.frame", class(.Object))
+            if (!"labelDescription" %in% colnames(varMetadata))
+                varMetadata[["labelDescription"]] <-
+                    rep(NA, nrow(varMetadata))
+            row.names(varMetadata) <- names(data)
+        }
+        varMetadata[["labelDescription"]] <-
+            as.character(varMetadata[["labelDescription"]])
+    }, error=function(err) {
+        stop(conditionMessage(err),
+             "\n  AnnotatedDataFrame 'initialize' could not update varMetadata:",
+             "\n  perhaps pData and varMetadata are inconsistent?")
+    })
+    callNextMethod(.Object, data=data, varMetadata=varMetadata, ...)
+})
 
-validAnnotatedDataFrame <- function( object ) {
+validAnnotatedDataFrame <- function( object ) 
+{
     msg <- NULL
     if (!is(object, "AnnotatedDataFrame"))
-      msg <- paste(msg, paste("Cannot validate", class(object), "as AnnotatedDataFrame" ), sep = "\n  ")
-    if (length(row.names(varMetadata(object))) != length(colnames(pData(object))))
-      msg <- paste(msg, "All AnnotatedDataFrame pData column names must be present as rows in varMetadata, and vice versa", sep="\n")
+        msg <- c(msg, paste("cannot validate", class(object),
+                            "as AnnotatedDataFrame" ))
+    if (length(row.names(varMetadata(object))) !=
+        length(colnames(pData(object))))
+        msg <- c(msg, paste("all AnnotatedDataFrame pData column names",
+                            "must be present as rows in varMetadata",
+                            "and vice versa"))
     else if (any(row.names(varMetadata(object)) != colnames(pData(object))))
-      msg <- paste(msg, "AnnotatedDataFrame colnames of data differ from row.names of varMetadata", sep="\n  ")
+      msg <- c(msg, paste("AnnotatedDataFrame colnames of data differ",
+                          "from row.names of varMetadata"))
     if ( !("labelDescription" %in% colnames(varMetadata(object))))
-      msg <- paste(msg, "AnnotatedDataFrame varMetadata missing labelDescription column", sep="\n  ")
+      msg <- c(msg, paste("AnnotatedDataFrame varMetadata",
+                          "missing labelDescription column"))
     if (length(dimLabels(object))!=2)
-      msg <- paste(msg, "dimLabels must be a character vector of length 2", sep="\n  ")
+      msg <- c(msg, "dimLabels must be a character vector of length 2")
     if (is.null(msg)) TRUE else msg
 }
 
@@ -136,16 +147,19 @@ setReplaceMethod("pData",
                      initialize(object, data=value, varMetadata=varMetadata)
                  })
 
-setMethod("sampleNames", "AnnotatedDataFrame", function(object) row.names(object@data))
+setMethod("sampleNames", "AnnotatedDataFrame",
+    function(object) row.names(object@data))
 
-setReplaceMethod("sampleNames", c("AnnotatedDataFrame", "ANY"), function(object, value) {
-  if (length(value) != dim(object@data)[[1]])
-    stop(paste("number of new names (",
-               length(value),
-               ") should equal number of rows in AnnotatedDataFrame (",
-               dim( object )[[1]], ")",sep=""))
-  row.names(object@data) <- value
-  object
+setReplaceMethod("sampleNames",
+    signature(object="AnnotatedDataFrame", value="ANY"),
+    function(object, value) 
+{
+    if (length(value) != dim(object@data)[[1]])
+        stop("number of new names (", length(value), ") ",
+             "should equal number of rows in AnnotatedDataFrame (",
+             dim( object )[[1]], ")")
+    row.names(object@data) <- value
+    object
 })
 
 setMethod("featureNames",
@@ -161,15 +175,17 @@ setReplaceMethod("featureNames",
 
 setMethod("varLabels", "AnnotatedDataFrame", function(object) colnames(object@data))
 
-setReplaceMethod("varLabels", c("AnnotatedDataFrame", "ANY"), function(object, value) {
-  if (length(value) != dim(object@data)[[2]])
-    stop(paste("number of new varLabels (",
-               length(value),
-               ") should equal number of columns in AnnotatedDataFrame (",
-               dim(object)[[2]], ")", sep=""))
-  colnames(object@data) <- value
-  row.names(object@varMetadata) <- value
-  object
+setReplaceMethod("varLabels",
+    signature("AnnotatedDataFrame", "ANY"),
+    function(object, value) 
+{
+    if (length(value) != dim(object@data)[[2]])
+        stop("number of new varLabels (", length(value), ") ",
+             "should equal number of columns in AnnotatedDataFrame (",
+             dim(object)[[2]], ")")
+    colnames(object@data) <- value
+    row.names(object@varMetadata) <- value
+    object
 })
 
 setMethod("varMetadata", "AnnotatedDataFrame",
@@ -181,20 +197,23 @@ setReplaceMethod("varMetadata", c("AnnotatedDataFrame", "data.frame"),
     if (!("labelDescription" %in% colnames(value)))
         warning("'varMetadata' must have column 'labelDescription'")
     rinfo <- .row_names_info(value)
-    if (0L <= rinfo) {
-        ## not 'automatic'
-        bad <- setdiff(row.names(value), varLabels(object))
-        if (length(bad)) {
-            fmt <- "'%s' not in 'varLabels(<AnnotatedDataFrame>)'"
-            stop(sprintf(fmt, paste(selectSome(bad), collapse="', '")))
+    if (0L != length(varLabels(object))) {
+        if (0L <= rinfo) {
+            ## not 'automatic'
+            bad <- setdiff(row.names(value), varLabels(object))
+            if (0L != length(bad)) {
+                fmt <- "'%s' not in 'varLabels(<AnnotatedDataFrame>)'"
+                nms <- paste(selectSome(bad), collapse="', '")
+                stop(sprintf(fmt, nms))
+            }
         }
+        if (ncol(object) != abs(rinfo)) {
+            fmt <- "varMetadata has %d row(s), 'value' has %d"
+            stop(sprintf(fmt, ncol(object), nrow(value)))
+        }
+        if (0 < ncol(pData(object)))
+            row.names(value) <- names(pData(object))
     }
-    if (ncol(object) != abs(rinfo)) {
-        fmt <- "varMetadata has %d row(s); 'value' has %d"
-        stop(sprintf(fmt, ncol(object), nrow(value)))
-    }
-    if (0 < ncol(pData(object)))
-        row.names(value) <- names(pData(object))
     object@varMetadata <- value
     object
 })
@@ -313,8 +332,7 @@ setMethod("selectSomeIndex",
 .showAnnotatedDataFrame <-
     function(object, labels=list(0)) 
 {
-    lbls <- list(object=paste("An object of class \"",
-                   class(object), "\"", sep=""),
+    lbls <- list(object=paste0("An object of class '", class(object), "'"),
                  sampleNames=dimLabels(object)[[1]],
                  varMetadata="varMetadata",
                  varLabels="varLabels")
@@ -353,16 +371,16 @@ setMethod("combine",
           signature(x="AnnotatedDataFrame", y="AnnotatedDataFrame"),
           function(x, y) {
               if (class(x) != class(y)) {
-                  msg <- sprintf("'%s' objects have diffrenent classes '%s', '%s'",
-                                 "combine,AnnotatedDataFrame,AnnotatedDataFrame-method",
-                                 class(x), class(y))
-                  stop(msg)
+                  fmt <- "'%s' objects have diffrenent classes '%s', '%s'"
+                  txt0 <- "combine,AnnotatedDataFrame,AnnotatedDataFrame-method"
+                  stop(sprintf(fmt, txt0, class(x), class(y)))
               }
               if (!identical(dimLabels(x),dimLabels(y))) {
-                  msg <- sprintf("AnnotatedDataFrame dimLabels differ:\n    %s\n    %s\n  try 'updateObject'?",
-                                 paste(dimLabels(x), collapse=", "),
-                                 paste(dimLabels(y), collapse=", "))
-                  stop(msg)
+                  fmt <- paste("AnnotatedDataFrame dimLabels differ:\n",
+                               "    %s\n",
+                               "    %s\n  try 'updateObject'?")
+                  stop(sprintf(fmt, paste(dimLabels(x), collapse=", "),
+                               paste(dimLabels(y), collapse=", ")))
               }
 
               pDataX <- pData(x)
@@ -371,7 +389,8 @@ setMethod("combine",
 
               varMetadataX <- varMetadata(x)
               varMetadataY <- varMetadata(y)
-              ## labelDescription is required, likely a factor with conflicting levels
+              ## labelDescription is required, likely a factor with
+              ## conflicting levels
               if (is.factor(varMetadataX$labelDescription) &&
                   is.factor(varMetadataY$labelDescription)) {
                   f <- factor(c(as.character(varMetadataX$labelDescription),
@@ -414,7 +433,7 @@ read.AnnotatedDataFrame <-
       row.names=row.names, comment.char=varMetadata.char, ...)
     
     ## read varMetadata section (the lines with leading "#")
-    vmd = grep(paste("^",  varMetadata.char, sep=""),
+    vmd = grep(paste0("^",  varMetadata.char),
       readLines(filename), value=TRUE)
     svmd = strsplit(vmd, ":")
     varNames = sub("^# *", "", sapply(svmd, "[", 1L))
@@ -443,7 +462,7 @@ setMethod("AnnotatedDataFrame",
       function(data, varMetadata, dimLabels=c("rowNames", "columnNames"), ...)
 {
     AnnotatedDataFrame(data=data.frame(), varMetadata=data.frame(),
-                   dimLabels=dimLabels)
+                   dimLabels=dimLabels, ...)
 })
 
 setMethod("AnnotatedDataFrame",
@@ -468,7 +487,7 @@ setMethod("AnnotatedDataFrame",
     varMetadata[["labelDescription"]] <-
         as.character(varMetadata[["labelDescription"]])
     new("AnnotatedDataFrame", data=data, varMetadata=varMetadata,
-        dimLabels=dimLabels)
+        dimLabels=dimLabels, ...)
 })
 
 
