@@ -110,23 +110,12 @@ setReplaceMethod("exprs", signature(object="ExpressionSet",value="matrix"),
                  function(object, value) assayDataElementReplace(object, "exprs", value))
 
 
-setMethod("geneNames", signature(object="ExpressionSet"),
-          function(object) {
-              .Defunct("featureNames", "Biobase")
-          })
-setReplaceMethod("geneNames", signature(object="ExpressionSet",
-                                        value="character"),
-          function(object, value) {
-              .Defunct("featureNames<-", "Biobase")
-          })
-
-
 .esApply <- function(X, MARGIN, FUN, ...) {
     parent <- environment(FUN)
     if (is.null(parent))
         parent <- emptyenv()
     e1 <- new.env(parent=parent)
-    multiassign(names(pData(X)), pData(X), env=e1)
+    multiassign(names(pData(X)), pData(X), envir=e1)
     environment(FUN) <- e1
     apply(exprs(X), MARGIN, FUN, ...)
 }
@@ -149,7 +138,7 @@ setMethod("makeDataPackage",
                 VERSION=as.character(package_version(packageVersion)),
                 LICENSE=license,
                 TITLE = paste("Experimental Data Package:",packageName),
-                MAINTAINER = paste(author, ", <", email, ">", sep = ""),
+                MAINTAINER = paste0(author, ", <", email, ">"),
                 BVIEWS = biocViews,
                 DESCRIPTION = description,
                 FORMAT = pD2Rd(phenoData(object)))
@@ -161,7 +150,7 @@ setMethod("makeDataPackage",
               ##save the data file
               datadir = file.path(res$pkgdir, "data")
               dir.create(datadir, showWarnings=FALSE)
-              outfile = file.path(datadir, paste(packageName, ".rda", sep=""))
+              outfile = file.path(datadir, paste0(packageName, ".rda"))
               assign(packageName, object)
               save(list=packageName, file = outfile)
 
@@ -280,5 +269,3 @@ setMethod(ExpressionSet,
         featureData=featureData, experimentData=experimentData,
         annotation=annotation, protocolData=protocolData, ...)
 })
-
-
