@@ -267,7 +267,8 @@ setReplaceMethod("preproc",
 setMethod("show",
           signature=signature(object="eSet"),
           function(object) {
-              cat(class( object ), " (storageMode: ", storageMode(object), ")\n", sep="")
+              cat(class(object), " (storageMode: ",
+                  storageMode(object), ")\n", sep="")
               adim <- dim(object)
               if (length(adim)>1)
                   cat("assayData:",
@@ -343,6 +344,16 @@ setReplaceMethod("featureNames",
                      unsafeSetSlot(object, "assayData", ad)
                  })
 
+setMethod("dimnames", "eSet", function(x) {
+    list(featureNames(x), sampleNames(x))
+})
+
+setReplaceMethod("dimnames", "eSet", function(x, value) {
+    featureNames(x) <- value[[1]]
+    sampleNames(x) <- value[[2]]
+    x
+})
+
 setMethod("dim", "eSet", function(x) assayDataDim(assayData(x)))
 
 setMethod("dims", "eSet", function(object) assayDataDims(assayData(object)))
@@ -660,8 +671,8 @@ setMethod("combine",
             x="eSet", y="eSet"),
           function(x, y, ...) {
               if (class(x) != class(y))
-                stop(paste("objects must be the same class, but are ",
-                           class(x), ", ", class(y), sep=""))
+                stop("objects must be the same class, but are '",
+                     class(x), "', '", class(y), "'")
               if (any(annotation(x) != annotation(y)))
                 stop("objects have different annotations: ",
                      annotation(x), ", ", annotation(y))
@@ -676,24 +687,3 @@ setMethod("combine",
               x
           })
 
-##
-## Defunct methods
-##
-
-setMethod("reporterNames", "eSet", function(object) {
-  .Defunct("featureNames", "Biobase")
-})
-setReplaceMethod("reporterNames", c("eSet", "character"), function(object, value) {
-  .Defunct("featureNames<-", "Biobase")
-})
-
-setMethod("eList", "eSet", function(object) {
-  .Defunct("assayData", "Biobase")
-})
-setReplaceMethod("eList", c("eSet", "AssayData"), function(object, value) {
-  .Defunct("assayData<-", "Biobase")
-})
-
-setMethod("getExpData", c("eSet", "character"), function(object, name) {
-  .Defunct("assayData", "Biobase")
-})
