@@ -24,6 +24,8 @@ setMethod("rowQ", signature(imat="matrix", which="numeric"),
                 stop("cannot handle missing values.")
               if (length(which) != 1 || !is.finite(which))
                 stop("'which' must be length one and finite numeric")
+              if(is.integer(imat))
+                  imat <- structure(as.numeric(imat), dim=dim(imat))
               .Call("rowQ", imat, which, PACKAGE="Biobase")
           })
 
